pub struct AppserviceTokenOptional;Available on crate feature
api only.Expand description
No authentication is performed for clients, but it can be performed for appservices, by
including an appservice access token in the Authorization http header, or an
access_token query parameter.
Using the query parameter is deprecated since Matrix 1.11.