ClientScopedAuthScheme

Trait ClientScopedAuthScheme 

pub trait ClientScopedAuthScheme: AuthScheme { }
Available on crate feature api only.
A marker trait indicating that endpoints which use this auth scheme require clients authenticated using the OAuth 2.0 API to request certain scopes. See Metadata::required_client_scopes() for more information.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors